@@ -5,7 +5,7 @@ from functools import wraps
 from tqdm import tqdm
 
 
-class Tqmp(tqdm):
+class Tqdm(tqdm):
     def __init__(self, **kwargs):
         tqdm.__init__(self, **kwargs)
 
